# Generated by Django 4.2 on 2025-11-02 14:55

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BotHook',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='机器人名称')),
                ('webhook', models.CharField(blank=True, max_length=255, null=True, verbose_name='机器人webhook')),
                ('secret', models.CharField(blank=True, max_length=255, null=True, verbose_name='机器人secret')),
                ('extra', models.TextField(blank=True, default='{}', null=True, verbose_name='全部信息')),
            ],
            options={
                'verbose_name': '钉钉机器人钩子',
                'verbose_name_plural': '钉钉机器人钩子',
                'db_table': 'dingtalk_bot_hook',
            },
        ),
        migrations.CreateModel(
            name='Department',
            fields=[
                ('create_time', models.DateTimeField(auto_now_add=True, null=True, verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, null=True, verbose_name='更新时间')),
                ('sync_status', models.BooleanField(blank=True, default=False, null=True, verbose_name='同步状态')),
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False, verbose_name='部门id')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='部门名称')),
                ('parent_id', models.CharField(blank=True, max_length=255, null=True, verbose_name='父部门id')),
                ('order', models.IntegerField(blank=True, default=0, null=True, verbose_name='部门排序')),
                ('extra', models.TextField(blank=True, default='{}', null=True, verbose_name='全部信息')),
            ],
            options={
                'verbose_name': '钉钉部门',
                'verbose_name_plural': '钉钉部门',
                'db_table': 'dingtalk_department',
            },
        ),
        migrations.CreateModel(
            name='UserInfo',
            fields=[
                ('create_time', models.DateTimeField(auto_now_add=True, null=True, verbose_name='创建时间')),
                ('update_time', models.DateTimeField(auto_now=True, null=True, verbose_name='更新时间')),
                ('sync_status', models.BooleanField(blank=True, default=False, null=True, verbose_name='同步状态')),
                ('id', models.CharField(max_length=255, primary_key=True, serialize=False, verbose_name='钉钉用户id')),
                ('mobile', models.CharField(blank=True, max_length=255, null=True, verbose_name='手机号')),
                ('name', models.CharField(blank=True, max_length=255, null=True, verbose_name='姓名')),
                ('avatar', models.CharField(blank=True, max_length=255, null=True, verbose_name='头像')),
                ('email', models.CharField(blank=True, max_length=255, null=True, verbose_name='邮箱')),
                ('job_number', models.CharField(blank=True, max_length=255, null=True, verbose_name='工号')),
                ('department', models.CharField(blank=True, max_length=255, null=True, verbose_name='部门')),
                ('position', models.CharField(blank=True, max_length=255, null=True, verbose_name='职位')),
                ('extra', models.TextField(blank=True, default='{}', null=True, verbose_name='全部信息')),
                ('access_token', models.CharField(blank=True, max_length=255, null=True, verbose_name='access_token')),
                ('expires_in', models.IntegerField(blank=True, default=0, null=True, verbose_name='过期时间')),
                ('refresh_token', models.CharField(blank=True, max_length=255, null=True, verbose_name='refresh_token')),
            ],
            options={
                'verbose_name': '钉钉用户信息',
                'verbose_name_plural': '钉钉用户信息',
                'db_table': 'dingtalk_user_info',
            },
        ),
    ]
