# Generated by Django 4.2 on 2025-11-02 14:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rick_base', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='bothook',
            name='name',
        ),
        migrations.AddField(
            model_name='bothook',
            name='hook_name',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='机器人名称'),
        ),
    ]
